---
title: How to add media files? 
layout: page 
date: 2014-09-11
---

The source structure of a project is preserved in the built website, and all
non-markdown content files are copied verbatim. See [/manual/structure]. 

Therefore, you can put media files at any convenient place in the source, and
refer to them using Markdown image syntax, with a relative or root-relative
path to the source file.
